Development — SoL 3 user manual

### Navigation

- index
- previous |
- User manual »
- Appendixes »

# Development

SoL development is carried on in a git repository on Bitbucket.

You can visit the latest changes page to see what’s happened recently.

If you are a developer, you are more than welcome to fork it and adapt or improve it to fit your needs, and I will happily integrate back the changes you may contribute.

Alternatively you can translate it into another language, using the online Weblate service.

There is also some technical documentation automatically extracted from the sources.

### Navigation

- index
- previous |
- User manual »
- Appendixes »